@@ -53,6 +53,7 @@ Q_GLOBAL_STATIC_WITH_ARGS(KindMap, kindMap, ( {
     { Component::KindService, QLatin1String("service") },
     { Component::KindRepository, QLatin1String("repository") },
     { Component::KindOperatingSystem, QLatin1String("operating-system") },
+    { Component::KindIconTheme, QLatin1String("icon-theme") },
     { Component::KindUnknown, QLatin1String("unknown") }
     }
 ));
@@ -107,6 +108,9 @@ Component::Kind Component::stringToKind(const QString& kindString) {
     if (kindString == QLatin1String("operating-system"))
         return KindOperatingSystem;
 
+    if (kindString == QLatin1String("icon-theme"))
+        return KindIconTheme;
+
     return KindUnknown;
 
 }
@@ -148,6 +152,16 @@ QString Component::urlKindToString(Component::UrlKind kind) {
     return urlKindMap->value(kind);
 }
 
+QString Component::scopeToString(Component::Scope scope)
+{
+    return QString::fromUtf8(as_component_scope_to_string(static_cast<AsComponentScope>(scope)));
+}
+
+Component::Scope Component::stringToScope(const QString& scopeString)
+{
+    return static_cast<Component::Scope>(as_component_scope_from_string(qPrintable(scopeString)));
+}
+
 Component::Component(const Component& other)
     : m_cpt(other.m_cpt)
 {
@@ -249,6 +263,16 @@ void Component::setDataId(const QString& cdid)
     as_component_set_data_id(m_cpt, qPrintable(cdid));
 }
 
+Component::Scope Component::scope() const
+{
+    return static_cast<Component::Scope>(as_component_get_scope (m_cpt));
+}
+
+void Component::setScope(Component::Scope scope)
+{
+    as_component_set_scope(m_cpt, static_cast<AsComponentScope>(scope));
+}
+
 QStringList Component::packageNames() const
 {
     return valueWrap(as_component_get_pkgnames(m_cpt));
