@@ -22,7 +22,7 @@
 /**
  * SECTION:as-agreement
  * @short_description: Object representing a privacy policy
- * @include: appstream-glib.h
+ * @include: appstream.h
  * @stability: Unstable
  *
  * Agreements can be used by components to specify GDPR, EULA or other warnings.
@@ -431,78 +431,6 @@ as_agreement_emit_yaml (AsAgreement *agreement, AsContext *ctx, yaml_emitter_t *
 	as_yaml_mapping_end (emitter);
 }
 
-/**
- * as_agreement_to_variant:
- * @agreement: an #AsAgreement
- * @builder: A #GVariantBuilder
- *
- * Serialize the current active state of this object to a GVariant
- * for use in the on-disk binary cache.
- */
-void
-as_agreement_to_variant (AsAgreement *agreement, GVariantBuilder *builder)
-{
-	AsAgreementPrivate *priv = GET_PRIVATE (agreement);
-	GVariantBuilder sections_b;
-	GVariantBuilder agreement_b;
-
-	g_variant_builder_init (&agreement_b, G_VARIANT_TYPE_ARRAY);
-	g_variant_builder_add_parsed (&agreement_b, "{'kind', <%u>}", priv->kind);
-	g_variant_builder_add_parsed (&agreement_b, "{'version_id', %v}", as_variant_mstring_new (priv->version_id));
-
-	g_variant_builder_init (&sections_b, (const GVariantType *) "aa{sv}");
-	for (guint i = 0; i < priv->sections->len; i++) {
-		as_agreement_section_to_variant (AS_AGREEMENT_SECTION (g_ptr_array_index (priv->sections, i)), &sections_b);
-	}
-
-	as_variant_builder_add_kv (&agreement_b, "sections", g_variant_builder_end (&sections_b));
-	g_variant_builder_add_value (builder, g_variant_builder_end (&agreement_b));
-}
-
-/**
- * as_agreement_set_from_variant:
- * @agreement: an #AsAgreement
- * @variant: The #GVariant to read from.
- *
- * Read the active state of this object from a #GVariant serialization.
- * This is used by the on-disk binary cache.
- */
-gboolean
-as_agreement_set_from_variant (AsAgreement *agreement, GVariant *variant, const gchar *locale)
-{
-	AsAgreementPrivate *priv = GET_PRIVATE (agreement);
-	GVariant *tmp;
-	GVariantDict adict;
-
-	g_variant_dict_init (&adict, variant);
-
-	priv->kind = as_variant_get_dict_uint32 (&adict, "kind");
-
-	as_agreement_set_version_id (agreement, as_variant_get_dict_mstr (&adict, "version_id", &tmp));
-	g_variant_unref (tmp);
-
-	/* sizes */
-	tmp = g_variant_dict_lookup_value (&adict, "sections", G_VARIANT_TYPE_ARRAY);
-	if (tmp != NULL) {
-		GVariant *inner_child;
-		GVariantIter siter;
-
-		g_variant_iter_init (&siter, tmp);
-		while ((inner_child = g_variant_iter_next_value (&siter))) {
-			g_autoptr(AsAgreementSection) asec = as_agreement_section_new ();
-
-			if (!as_agreement_section_set_from_variant (asec, inner_child, locale))
-				return FALSE;
-			as_agreement_add_section (agreement, asec);
-
-			g_variant_unref (inner_child);
-		}
-		g_variant_unref (tmp);
-	}
-
-	return TRUE;
-}
-
 /**
  * as_agreement_new:
  *
