@@ -179,15 +179,14 @@ as_checksum_load_from_xml (AsChecksum *cs, AsContext *ctx, xmlNode *node, GError
 {
 	AsChecksumPrivate *priv = GET_PRIVATE (cs);
 	g_autofree gchar *prop = NULL;
-	g_autofree gchar *content = NULL;
 
 	prop = (gchar*) xmlGetProp (node, (xmlChar*) "type");
 	priv->kind = as_checksum_kind_from_string (prop);
 	if (priv->kind == AS_CHECKSUM_KIND_NONE)
 		return FALSE;
 
-	content = as_xml_get_node_value (node);
-	as_checksum_set_value (cs, content);
+	g_free (priv->value);
+	priv->value = as_xml_get_node_value (node);
 
 	return TRUE;
 }
@@ -260,42 +259,6 @@ as_checksum_emit_yaml (AsChecksum *cs, AsContext *ctx, yaml_emitter_t *emitter)
 	as_yaml_emit_entry (emitter, as_checksum_kind_to_string (priv->kind), priv->value);
 }
 
-/**
- * as_checksum_to_variant:
- * @cs: a #AsChecksum instance.
- * @builder: A #GVariantBuilder
- *
- * Serialize the current active state of this object to a GVariant
- * for use in the on-disk binary cache.
- */
-void
-as_checksum_to_variant (AsChecksum *cs, GVariantBuilder *builder)
-{
-	AsChecksumPrivate *priv = GET_PRIVATE (cs);
-
-	g_variant_builder_add (builder, "{us}", priv->kind, priv->value);
-}
-
-/**
- * as_checksum_set_from_variant:
- * @cs: a #AsChecksum instance.
- * @variant: The #GVariant to read from.
- *
- * Read the active state of this object from a #GVariant serialization.
- * This is used by the on-disk binary cache.
- */
-gboolean
-as_checksum_set_from_variant (AsChecksum *cs, GVariant *variant)
-{
-	AsChecksumPrivate *priv = GET_PRIVATE (cs);
-
-	g_free (priv->value);
-	priv->value = NULL;
-	g_variant_get (variant, "{us}", &priv->kind, &priv->value);
-
-	return TRUE;
-}
-
 /**
  * as_checksum_new:
  *
