@@ -48,9 +48,6 @@ typedef enum {
 	AS_ORIGIN_KIND_LAST
 } AsOriginKind;
 
-const gchar		*as_component_scope_to_string (AsComponentScope scope);
-AsMergeKind		as_component_scope_from_string (const gchar *scope_str);
-
 typedef guint16		AsTokenType; /* big enough for both bitshifts */
 
 AS_INTERNAL_VISIBLE
@@ -92,10 +89,6 @@ void			as_component_set_sort_score (AsComponent *cpt,
 void			as_component_set_ignored (AsComponent *cpt,
 						  gboolean ignore);
 
-AsComponentScope	as_component_get_scope (AsComponent *cpt);
-void			as_component_set_scope (AsComponent *cpt,
-						AsComponentScope scope);
-
 AsOriginKind		as_component_get_origin_kind (AsComponent *cpt);
 void			as_component_set_origin_kind (AsComponent *cpt,
 							AsOriginKind okind);
@@ -126,12 +119,6 @@ void			as_component_emit_yaml (AsComponent *cpt,
 						AsContext *ctx,
 						yaml_emitter_t *emitter);
 
-void			as_component_to_variant (AsComponent *cpt,
-						 GVariantBuilder *builder);
-gboolean		as_component_set_from_variant (AsComponent *cpt,
-							GVariant *variant,
-							const gchar *locale);
-
 #pragma GCC visibility pop
 G_END_DECLS
 
