@@ -50,11 +50,6 @@ void		as_content_rating_emit_yaml (AsContentRating *content_rating,
 						AsContext *ctx,
 						yaml_emitter_t *emitter);
 
-void		as_content_rating_to_variant (AsContentRating *content_rating,
-					      GVariantBuilder *builder);
-gboolean	as_content_rating_set_from_variant (AsContentRating *content_rating,
-						    GVariant *variant);
-
 #pragma GCC visibility pop
 G_END_DECLS
 
