@@ -44,6 +44,7 @@ typedef struct
 	gchar			*fname;
 	gint 			priority;
 
+	gboolean		internal_mode;
 	gboolean		all_locale;
 } AsContextPrivate;
 
@@ -73,8 +74,9 @@ as_context_init (AsContext *ctx)
 
 	priv->format_version = AS_CURRENT_FORMAT_VERSION;
 	priv->style = AS_FORMAT_STYLE_UNKNOWN;
-	priv->fname = g_strdup (":memory:");
+	priv->fname = g_strdup (":memory");
 	priv->priority = 0;
+	priv->internal_mode = FALSE;
 }
 
 static void
@@ -338,6 +340,35 @@ as_context_set_filename (AsContext *ctx, const gchar *fname)
 	priv->fname = g_strdup (fname);
 }
 
+/**
+ * as_context_get_internal_mode:
+ * @ctx: a #AsContext instance.
+ *
+ * Returns: %TRUE if internal-mode XML is generated.
+ **/
+gboolean
+as_context_get_internal_mode (AsContext *ctx)
+{
+	AsContextPrivate *priv = GET_PRIVATE (ctx);
+	return priv->internal_mode;
+}
+
+/**
+ * as_context_set_internal_mode:
+ * @ctx: a #AsContext instance.
+ * @enabled: %TRUE if enabled.
+ *
+ * In internal mode, serializers will generate
+ * a bit of additional XML used internally by AppStream
+ * (e.g. for database serialization).
+ **/
+void
+as_context_set_internal_mode (AsContext *ctx, gboolean enabled)
+{
+	AsContextPrivate *priv = GET_PRIVATE (ctx);
+	priv->internal_mode = enabled;
+}
+
 /**
  * as_context_new:
  *
