@@ -27,7 +27,7 @@
 G_BEGIN_DECLS
 #pragma GCC visibility push(hidden)
 
-time_t			as_pool_get_cache_age (AsPool *pool);
+time_t			as_pool_get_system_cache_age (AsPool *pool);
 
 AS_INTERNAL_VISIBLE
 void			as_cache_file_save (const gchar *fname,
@@ -39,6 +39,11 @@ AS_INTERNAL_VISIBLE
 GPtrArray		*as_cache_file_read (const gchar *fname,
 						GError **error);
 
+AS_INTERNAL_VISIBLE
+gboolean		as_pool_refresh_system_cache (AsPool *pool,
+							gboolean force,
+							GError **error);
+
 #pragma GCC visibility pop
 G_END_DECLS
 
