@@ -27,7 +27,6 @@
 #include <fnmatch.h>
 
 #include "as-utils.h"
-#include "as-variant-cache.h"
 
 /**
  * SECTION:as-provided
@@ -66,8 +65,8 @@ as_provided_kind_to_string (AsProvidedKind kind)
 		return "lib";
 	if (kind == AS_PROVIDED_KIND_BINARY)
 		return "bin";
-	if (kind == AS_PROVIDED_KIND_MIMETYPE)
-		return "mimetype";
+	if (kind == AS_PROVIDED_KIND_MEDIATYPE)
+		return "mediatype";
 	if (kind == AS_PROVIDED_KIND_FONT)
 		return "font";
 	if (kind == AS_PROVIDED_KIND_MODALIAS)
@@ -104,8 +103,8 @@ as_provided_kind_from_string (const gchar *kind_str)
 		return AS_PROVIDED_KIND_LIBRARY;
 	if (g_strcmp0 (kind_str, "bin") == 0)
 		return AS_PROVIDED_KIND_BINARY;
-	if (g_strcmp0 (kind_str, "mimetype") == 0)
-		return AS_PROVIDED_KIND_MIMETYPE;
+	if (g_strcmp0 (kind_str, "mediatype") == 0)
+		return AS_PROVIDED_KIND_MEDIATYPE;
 	if (g_strcmp0 (kind_str, "font") == 0)
 		return AS_PROVIDED_KIND_FONT;
 	if (g_strcmp0 (kind_str, "modalias") == 0)
@@ -145,8 +144,8 @@ as_provided_kind_to_l10n_string (AsProvidedKind kind)
 		return _("Libraries");
 	if (kind == AS_PROVIDED_KIND_BINARY)
 		return _("Binaries");
-	if (kind == AS_PROVIDED_KIND_MIMETYPE)
-		return _("MIME types");
+	if (kind == AS_PROVIDED_KIND_MEDIATYPE)
+		return _("Media types");
 	if (kind == AS_PROVIDED_KIND_FONT)
 		return _("Fonts");
 	if (kind == AS_PROVIDED_KIND_MODALIAS)
@@ -156,9 +155,9 @@ as_provided_kind_to_l10n_string (AsProvidedKind kind)
 	if (kind == AS_PROVIDED_KIND_PYTHON)
 		return _("Python 3");
 	if (kind == AS_PROVIDED_KIND_DBUS_SYSTEM)
-		return _("DBus System Services");
+		return _("D-Bus System Services");
 	if (kind == AS_PROVIDED_KIND_DBUS_USER)
-		return _("DBus Session Services");
+		return _("D-Bus Session Services");
 	if (kind == AS_PROVIDED_KIND_FIRMWARE_RUNTIME)
 		return _("Runtime Firmware");
 	if (kind == AS_PROVIDED_KIND_FIRMWARE_FLASHED)
@@ -292,53 +291,6 @@ as_provided_add_item (AsProvided *prov, const gchar *item)
 	g_ptr_array_add (priv->items, g_strdup (item));
 }
 
-/**
- * as_provided_to_variant:
- * @prov: a #AsProvided instance.
- * @builder: A #GVariantBuilder
- *
- * Serialize the current active state of this object to a GVariant
- * for use in the on-disk binary cache.
- */
-void
-as_provided_to_variant (AsProvided *prov, GVariantBuilder *builder)
-{
-	AsProvidedPrivate *priv = GET_PRIVATE (prov);
-	GVariant *prov_var;
-
-	prov_var = g_variant_new ("{uv}",
-				  priv->kind,
-				  as_variant_from_string_ptrarray (priv->items));
-	g_variant_builder_add_value (builder, prov_var);
-}
-
-/**
- * as_provided_set_from_variant:
- * @prov: a #AsProvided instance.
- * @variant: The #GVariant to read from.
- *
- * Read the active state of this object from a #GVariant serialization.
- * This is used by the on-disk binary cache.
- */
-gboolean
-as_provided_set_from_variant (AsProvided *prov, GVariant *variant)
-{
-	AsProvidedPrivate *priv = GET_PRIVATE (prov);
-	GVariantIter inner_iter;
-	GVariant *item_child;
-	g_autoptr(GVariant) items_var = NULL;
-
-	g_variant_get (variant, "{uv}", &priv->kind, &items_var);
-
-	g_variant_iter_init (&inner_iter, items_var);
-	while ((item_child = g_variant_iter_next_value (&inner_iter))) {
-		as_provided_add_item (prov, g_variant_get_string (item_child, NULL));
-		g_variant_unref (item_child);
-	}
-
-	return TRUE;
-}
-
 /**
  * as_provided_new:
  *
