@@ -48,12 +48,6 @@ void			as_screenshot_emit_yaml (AsScreenshot *screenshot,
 						 AsContext *ctx,
 						 yaml_emitter_t *emitter);
 
-gboolean		as_screenshot_to_variant (AsScreenshot *screenshot,
-						  GVariantBuilder *builder);
-gboolean		as_screenshot_set_from_variant (AsScreenshot *screenshot,
-							GVariant *variant,
-							const gchar *locale);
-
 #pragma GCC visibility pop
 G_END_DECLS
 
