@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2012-2017 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2012-2019 Matthias Klumpp <matthias@tenstral.net>
  * Copyright (C) 2014 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
@@ -23,10 +23,10 @@
  * SECTION:as-screenshot
  * @short_description: Object representing a single screenshot
  *
- * Screenshots have a localized caption and also contain a number of images
- * of different resolution.
+ * Screenshots have a localized caption and contain either a set of images
+ * of different resolution or a video screencast showcasing the software.
  *
- * See also: #AsImage
+ * See also: #AsImage, #AsVideo
  */
 
 #include "as-screenshot.h"
@@ -35,14 +35,18 @@
 #include "as-utils.h"
 #include "as-utils-private.h"
 #include "as-image-private.h"
-#include "as-variant-cache.h"
+#include "as-video-private.h"
 
 typedef struct
 {
 	AsScreenshotKind kind;
+	AsScreenshotMediaKind media_kind;
 	GHashTable *caption;
+
 	GPtrArray *images;
 	GPtrArray *images_lang;
+	GPtrArray *videos;
+	GPtrArray *videos_lang;
 
 	AsContext *context;
 	gchar *active_locale_override;
@@ -51,6 +55,23 @@ typedef struct
 G_DEFINE_TYPE_WITH_PRIVATE (AsScreenshot, as_screenshot, G_TYPE_OBJECT)
 #define GET_PRIVATE(o) (as_screenshot_get_instance_private (o))
 
+/**
+ * as_screenshot_init:
+ **/
+static void
+as_screenshot_init (AsScreenshot *screenshot)
+{
+	AsScreenshotPrivate *priv = GET_PRIVATE (screenshot);
+
+	priv->kind = AS_SCREENSHOT_KIND_EXTRA;
+	priv->media_kind = AS_SCREENSHOT_MEDIA_KIND_IMAGE;
+	priv->caption = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
+	priv->images = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
+	priv->images_lang = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
+	priv->videos = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
+	priv->videos_lang = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
+}
+
 /**
  * as_screenshot_finalize:
  **/
@@ -63,6 +84,8 @@ as_screenshot_finalize (GObject *object)
 	g_free (priv->active_locale_override);
 	g_ptr_array_unref (priv->images);
 	g_ptr_array_unref (priv->images_lang);
+	g_ptr_array_unref (priv->videos);
+	g_ptr_array_unref (priv->videos_lang);
 	g_hash_table_unref (priv->caption);
 	if (priv->context != NULL)
 		g_object_unref (priv->context);
@@ -70,20 +93,6 @@ as_screenshot_finalize (GObject *object)
 	G_OBJECT_CLASS (as_screenshot_parent_class)->finalize (object);
 }
 
-/**
- * as_screenshot_init:
- **/
-static void
-as_screenshot_init (AsScreenshot *screenshot)
-{
-	AsScreenshotPrivate *priv = GET_PRIVATE (screenshot);
-
-	priv->kind = AS_SCREENSHOT_KIND_EXTRA;
-	priv->caption = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
-	priv->images = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
-	priv->images_lang = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
-}
-
 /**
  * as_screenshot_class_init:
  **/
@@ -161,6 +170,21 @@ as_screenshot_set_kind (AsScreenshot *screenshot, AsScreenshotKind kind)
 	priv->kind = kind;
 }
 
+/**
+ * as_screenshot_get_media_kind:
+ * @screenshot: a #AsScreenshot instance.
+ *
+ * Gets the screenshot media kind.
+ *
+ * Returns: a #AsScreenshotMediaKind
+ **/
+AsScreenshotMediaKind
+as_screenshot_get_media_kind (AsScreenshot *screenshot)
+{
+	AsScreenshotPrivate *priv = GET_PRIVATE (screenshot);
+	return priv->media_kind;
+}
+
 /**
  * as_screenshot_get_images:
  * @screenshot: a #AsScreenshot instance.
@@ -196,6 +220,42 @@ as_screenshot_add_image (AsScreenshot *screenshot, AsImage *image)
 		g_ptr_array_add (priv->images_lang, g_object_ref (image));
 }
 
+/**
+ * as_screenshot_get_videos:
+ * @screenshot: a #AsScreenshot instance.
+ *
+ * Gets the videos for this screenshots. Only videos valid for the current
+ * language selection are returned. We return all sizes.
+ *
+ * Returns: (transfer none) (element-type AsVideo): an array
+ **/
+GPtrArray*
+as_screenshot_get_videos (AsScreenshot *screenshot)
+{
+	AsScreenshotPrivate *priv = GET_PRIVATE (screenshot);
+	if (priv->videos_lang->len == 0)
+		return priv->videos;
+	return priv->videos_lang;
+}
+
+/**
+ * as_screenshot_add_video:
+ * @screenshot: a #AsScreenshot instance.
+ * @video: a #AsVideo instance.
+ *
+ * Adds a video to the screenshot.
+ **/
+void
+as_screenshot_add_video (AsScreenshot *screenshot, AsVideo *video)
+{
+	AsScreenshotPrivate *priv = GET_PRIVATE (screenshot);
+	priv->media_kind = AS_SCREENSHOT_MEDIA_KIND_VIDEO;
+	g_ptr_array_add (priv->videos, g_object_ref (video));
+
+	if (as_utils_locale_is_compatible (as_video_get_locale (video), as_screenshot_get_active_locale (screenshot)))
+		g_ptr_array_add (priv->videos_lang, g_object_ref (video));
+}
+
 /**
  * as_screenshot_get_caption:
  * @screenshot: a #AsScreenshot instance.
@@ -256,26 +316,35 @@ as_screenshot_is_valid (AsScreenshot *screenshot)
 }
 
 /**
- * as_screenshot_rebuild_suitable_images_list:
+ * as_screenshot_rebuild_suitable_media_list:
  * @screenshot: a #AsScreenshot instance.
  *
- * Rebuild list of images suitable for the selected locale.
+ * Rebuild list of images or videos suitable for the selected locale.
  */
 static void
-as_screenshot_rebuild_suitable_images_list (AsScreenshot *screenshot)
+as_screenshot_rebuild_suitable_media_list (AsScreenshot *screenshot)
 {
 	AsScreenshotPrivate *priv = GET_PRIVATE (screenshot);
-	guint i;
 
 	/* rebuild our list of images suitable for the current locale */
 	g_ptr_array_unref (priv->images_lang);
 	priv->images_lang = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
-	for (i = 0; i < priv->images->len; i++) {
+	for (guint i = 0; i < priv->images->len; i++) {
 		AsImage *img = AS_IMAGE (g_ptr_array_index (priv->images, i));
 		if (!as_utils_locale_is_compatible (as_image_get_locale (img), as_screenshot_get_active_locale (screenshot)))
 			continue;
 		g_ptr_array_add (priv->images_lang, g_object_ref (img));
 	}
+
+	/* rebuild our list of videos suitable for the current locale */
+	g_ptr_array_unref (priv->videos_lang);
+	priv->videos_lang = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
+	for (guint i = 0; i < priv->videos->len; i++) {
+		AsVideo *vid = AS_VIDEO (g_ptr_array_index (priv->videos, i));
+		if (!as_utils_locale_is_compatible (as_video_get_locale (vid), as_screenshot_get_active_locale (screenshot)))
+			continue;
+		g_ptr_array_add (priv->videos_lang, g_object_ref (vid));
+	}
 }
 
 /**
@@ -321,7 +390,7 @@ as_screenshot_set_active_locale (AsScreenshot *screenshot, const gchar *locale)
 	priv->active_locale_override = g_strdup (locale);
 
 	/* rebuild our list of images suitable for the current locale */
-	as_screenshot_rebuild_suitable_images_list (screenshot);
+	as_screenshot_rebuild_suitable_media_list (screenshot);
 }
 
 /**
@@ -380,7 +449,7 @@ as_screenshot_set_context (AsScreenshot *screenshot, AsContext *context)
 	g_free (priv->active_locale_override);
 	priv->active_locale_override = NULL;
 
-	as_screenshot_rebuild_suitable_images_list (screenshot);
+	as_screenshot_rebuild_suitable_media_list (screenshot);
 }
 
 /**
@@ -418,6 +487,10 @@ as_screenshot_load_from_xml (AsScreenshot *screenshot, AsContext *ctx, xmlNode *
 			g_autoptr(AsImage) image = as_image_new ();
 			if (as_image_load_from_xml (image, ctx, iter, NULL))
 				as_screenshot_add_image (screenshot, image);
+		} else if (g_strcmp0 (node_name, "video") == 0) {
+			g_autoptr(AsVideo) video = as_video_new ();
+			if (as_video_load_from_xml (video, ctx, iter, NULL))
+				as_screenshot_add_video (screenshot, video);
 		} else if (g_strcmp0 (node_name, "caption") == 0) {
 			g_autofree gchar *content = NULL;
 			g_autofree gchar *lang = NULL;
@@ -464,7 +537,6 @@ as_screenshot_to_xml_node (AsScreenshot *screenshot, AsContext *ctx, xmlNode *ro
 {
 	AsScreenshotPrivate *priv = GET_PRIVATE (screenshot);
 	xmlNode *subnode;
-	guint i;
 
 	subnode = xmlNewChild (root, NULL, (xmlChar*) "screenshot", NULL);
 	if (priv->kind == AS_SCREENSHOT_KIND_DEFAULT)
@@ -472,9 +544,16 @@ as_screenshot_to_xml_node (AsScreenshot *screenshot, AsContext *ctx, xmlNode *ro
 
 	as_xml_add_localized_text_node (subnode, "caption", priv->caption);
 
-	for (i = 0; i < priv->images->len; i++) {
-		AsImage *image = AS_IMAGE (g_ptr_array_index (priv->images, i));
-		as_image_to_xml_node (image, ctx, subnode);
+	if (priv->media_kind == AS_SCREENSHOT_MEDIA_KIND_IMAGE) {
+		for (guint i = 0; i < priv->images->len; i++) {
+			AsImage *image = AS_IMAGE (g_ptr_array_index (priv->images, i));
+			as_image_to_xml_node (image, ctx, subnode);
+		}
+	} else if (priv->media_kind == AS_SCREENSHOT_MEDIA_KIND_VIDEO) {
+		for (guint i = 0; i < priv->videos->len; i++) {
+			AsVideo *video = AS_VIDEO (g_ptr_array_index (priv->videos, i));
+			as_video_to_xml_node (video, ctx, subnode);
+		}
 	}
 }
 
@@ -499,7 +578,7 @@ as_screenshot_load_from_yaml (AsScreenshot *screenshot, AsContext *ctx, GNode *n
 		const gchar *value = as_yaml_node_get_value (n);
 
 		if (g_strcmp0 (key, "default") == 0) {
-			if (g_strcmp0 (value, "yes") == 0)
+			if ((g_strcmp0 (value, "true") == 0) || (g_strcmp0 (value, "yes") == 0))
 				priv->kind = AS_SCREENSHOT_KIND_DEFAULT;
 			else
 				priv->kind = AS_SCREENSHOT_KIND_EXTRA;
@@ -518,6 +597,12 @@ as_screenshot_load_from_yaml (AsScreenshot *screenshot, AsContext *ctx, GNode *n
 				if (as_image_load_from_yaml (image, ctx, in, AS_IMAGE_KIND_THUMBNAIL, NULL))
 					as_screenshot_add_image (screenshot, image);
 			}
+		} else if (g_strcmp0 (key, "videos") == 0) {
+			for (in = n->children; in != NULL; in = in->next) {
+				g_autoptr(AsVideo) video = as_video_new ();
+				if (as_video_load_from_yaml (video, ctx, in, NULL))
+					as_screenshot_add_video (screenshot, video);
+			}
 		} else {
 			as_yaml_print_unknown ("screenshot", key);
 		}
@@ -541,7 +626,6 @@ void
 as_screenshot_emit_yaml (AsScreenshot *screenshot, AsContext *ctx, yaml_emitter_t *emitter)
 {
 	AsScreenshotPrivate *priv = GET_PRIVATE (screenshot);
-	guint i;
 	AsImage *source_img = NULL;
 
 	as_yaml_mapping_start (emitter);
@@ -551,107 +635,39 @@ as_screenshot_emit_yaml (AsScreenshot *screenshot, AsContext *ctx, yaml_emitter_
 
 	as_yaml_emit_localized_entry (emitter, "caption", priv->caption);
 
-	as_yaml_emit_scalar (emitter, "thumbnails");
-	as_yaml_sequence_start (emitter);
-	for (i = 0; i < priv->images->len; i++) {
-		AsImage *img = AS_IMAGE (g_ptr_array_index (priv->images, i));
+	if (priv->media_kind == AS_SCREENSHOT_MEDIA_KIND_IMAGE) {
+		as_yaml_emit_scalar (emitter, "thumbnails");
+		as_yaml_sequence_start (emitter);
+		for (guint i = 0; i < priv->images->len; i++) {
+			AsImage *img = AS_IMAGE (g_ptr_array_index (priv->images, i));
 
-		if (as_image_get_kind (img) == AS_IMAGE_KIND_SOURCE) {
-			source_img = img;
-			continue;
+			if (as_image_get_kind (img) == AS_IMAGE_KIND_SOURCE) {
+				source_img = img;
+				continue;
+			}
+
+			as_image_emit_yaml (img, ctx, emitter);
 		}
+		as_yaml_sequence_end (emitter);
 
-		as_image_emit_yaml (img, ctx, emitter);
-	}
-	as_yaml_sequence_end (emitter);
-
-	/* we *must* have a source-image by now if the data follows the spec, but better be safe... */
-	if (source_img != NULL) {
-		as_yaml_emit_scalar (emitter, "source-image");
-		as_image_emit_yaml (source_img, ctx, emitter);
+		/* we *must* have a source-image by now if the data follows the spec, but better be safe... */
+		if (source_img != NULL) {
+			as_yaml_emit_scalar (emitter, "source-image");
+			as_image_emit_yaml (source_img, ctx, emitter);
+		}
+	} else if (priv->media_kind == AS_SCREENSHOT_MEDIA_KIND_VIDEO) {
+		as_yaml_emit_scalar (emitter, "videos");
+		as_yaml_sequence_start (emitter);
+		for (guint i = 0; i < priv->videos->len; i++) {
+			AsVideo *video = AS_VIDEO (g_ptr_array_index (priv->videos, i));
+			as_video_emit_yaml (video, ctx, emitter);
+		}
+		as_yaml_sequence_end (emitter);
 	}
 
 	as_yaml_mapping_end (emitter);
 }
 
-/**
- * as_screenshot_to_variant:
- * @screenshot: an #AsScreenshot instance.
- * @builder: A #GVariantBuilder
- *
- * Serialize the current active state of this object to a GVariant
- * for use in the on-disk binary cache.
- *
- * Returns: %TRUE if a screenhot was added to the @builder
- */
-gboolean
-as_screenshot_to_variant (AsScreenshot *screenshot, GVariantBuilder *builder)
-{
-	AsScreenshotPrivate *priv = GET_PRIVATE (screenshot);
-	guint i;
-	GVariantBuilder images_b;
-	GVariantBuilder scr_b;
-
-	/* do not add screenshot without images to the cache */
-	if (priv->images->len == 0)
-		return FALSE;
-
-	g_variant_builder_init (&images_b, (const GVariantType *) "aa{sv}");
-	for (i = 0; i < priv->images->len; i++)
-		as_image_to_variant (AS_IMAGE (g_ptr_array_index (priv->images, i)), &images_b);
-
-	g_variant_builder_init (&scr_b, G_VARIANT_TYPE_ARRAY);
-	g_variant_builder_add_parsed (&scr_b, "{'type', <%u>}", priv->kind);
-	g_variant_builder_add_parsed (&scr_b, "{'caption', %v}", as_variant_mstring_new (as_screenshot_get_caption (screenshot)));
-	g_variant_builder_add_parsed (&scr_b, "{'images', %v}", g_variant_builder_end (&images_b));
-
-	g_variant_builder_add_value (builder, g_variant_builder_end (&scr_b));
-
-	return TRUE;
-}
-
-/**
- * as_screenshot_set_from_variant:
- * @screenshot: an #AsScreenshot instance.
- * @variant: The #GVariant to read from.
- *
- * Read the active state of this object from a #GVariant serialization.
- * This is used by the on-disk binary cache.
- */
-gboolean
-as_screenshot_set_from_variant (AsScreenshot *screenshot, GVariant *variant, const gchar *locale)
-{
-	AsScreenshotPrivate *priv = GET_PRIVATE (screenshot);
-	GVariantIter inner_iter;
-	g_auto(GVariantDict) idict;
-	GVariant *tmp;
-	g_autoptr(GVariant) images_var = NULL;
-
-	as_screenshot_set_active_locale (screenshot, locale);
-	g_variant_dict_init (&idict, variant);
-
-	priv->kind = as_variant_get_dict_uint32 (&idict, "type");
-	as_screenshot_set_caption (screenshot,
-				   as_variant_get_dict_mstr (&idict, "caption", &tmp),
-				   locale);
-	g_variant_unref (tmp);
-
-	images_var = g_variant_dict_lookup_value (&idict, "images", G_VARIANT_TYPE_ARRAY);
-	if (images_var != NULL) {
-		GVariant *img_child;
-		g_variant_iter_init (&inner_iter, images_var);
-
-		while ((img_child = g_variant_iter_next_value (&inner_iter))) {
-			g_autoptr(AsImage) img = as_image_new ();
-			if (as_image_set_from_variant (img, img_child))
-				as_screenshot_add_image (screenshot, img);
-			g_variant_unref (img_child);
-		}
-	}
-
-	return priv->images->len != 0;
-}
-
 /**
  * as_screenshot_new:
  *
