@@ -30,11 +30,11 @@ G_BEGIN_DECLS
 #define AS_INTERNAL_VISIBLE __attribute__((visibility("default")))
 
 #define AS_CONFIG_NAME "/etc/appstream.conf"
-#define AS_APPSTREAM_CACHE_PATH "/var/cache/app-info/gv"
+#define AS_APPSTREAM_CACHE_PATH "/var/cache/app-info/cache"
 
 /* declared in as-data-pool.c */
 AS_INTERNAL_VISIBLE
-extern const gchar *AS_APPSTREAM_METADATA_PATHS[4];
+extern const gchar *AS_SYSTEM_COLLECTION_METADATA_PATHS[4];
 
 #pragma GCC visibility pop
 G_END_DECLS
