@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2012-2016 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2012-2019 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -23,11 +23,36 @@
 
 #include <glib-object.h>
 #include "as-settings-private.h"
+#include "as-utils.h"
 #include "as-component.h"
 
 G_BEGIN_DECLS
 #pragma GCC visibility push(hidden)
 
+/**
+ * AsMarkupKind:
+ * @AS_MARKUP_KIND_UNKNOWN:	Unknown markup.
+ * @AS_MARKUP_KIND_XML:		XML markup.
+ * @AS_MARKUP_KIND_YAML:	YAML markup.
+ * @AS_MARKUP_KIND_TEXT:	Simple text.
+ * @AS_MARKUP_KIND_MARKDOWN:	Markdown
+ *
+ * Markup types.
+ **/
+typedef enum {
+	AS_MARKUP_KIND_UNKNOWN,
+	AS_MARKUP_KIND_XML,
+	AS_MARKUP_KIND_YAML,
+	AS_MARKUP_KIND_TEXT,
+	AS_MARKUP_KIND_MARKDOWN,
+	/*< private >*/
+	AS_MARKUP_KIND_LAST
+} AsMarkupKind;
+
+gchar			*as_description_markup_convert (const gchar *markup,
+							AsMarkupKind to_kind,
+							GError **error);
+
 gchar			*as_get_current_locale (void);
 
 gboolean		as_str_empty (const gchar* str);
@@ -91,6 +116,18 @@ AS_INTERNAL_VISIBLE
 gchar			*as_utils_dns_to_rdns (const gchar *url,
 					       const gchar *suffix);
 
+void			as_sort_components_by_score (GPtrArray *cpts);
+
+void			as_object_ptr_array_absorb (GPtrArray *dest,
+						    GPtrArray *src);
+
+AS_INTERNAL_VISIBLE
+gchar			*as_ptr_array_to_str (GPtrArray *array,
+						const gchar *separator);
+
+AS_INTERNAL_VISIBLE
+gchar			*as_filebasename_from_uri (const gchar *uri);
+
 #pragma GCC visibility pop
 G_END_DECLS
 
