@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2012-2016 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2012-2019 Matthias Klumpp <matthias@tenstral.net>
  * Copyright (C)      2016 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
@@ -68,16 +68,16 @@ as_get_appstream_version (void)
 }
 
 /**
- * as_description_markup_convert_simple:
- * @markup: the text to copy.
+ * as_description_markup_convert:
+ * @markup: the XML markup to transform.
  * @error: A #GError or %NULL.
  *
- * Converts an XML description markup into a simple printable form.
+ * Converts XML description markup into other forms of markup.
  *
  * Returns: (transfer full): a newly allocated %NULL terminated string.
  **/
 gchar*
-as_markup_convert_simple (const gchar *markup, GError **error)
+as_description_markup_convert (const gchar *markup, AsMarkupKind to_kind, GError **error)
 {
 	xmlDoc *doc = NULL;
 	xmlNode *root;
@@ -96,6 +96,10 @@ as_markup_convert_simple (const gchar *markup, GError **error)
 		goto out;
 	}
 
+	/* if we already have XML, do nothing */
+	if (to_kind == AS_MARKUP_KIND_XML)
+		goto out;
+
 	/* make XML parser happy by providing a root element */
 	xmldata = g_strdup_printf ("<root>%s</root>", markup);
 
@@ -114,29 +118,43 @@ as_markup_convert_simple (const gchar *markup, GError **error)
 
 	str = g_string_new ("");
 	for (iter = root->children; iter != NULL; iter = iter->next) {
-		gchar *content;
 		xmlNode *iter2;
 		/* discard spaces */
 		if (iter->type != XML_ELEMENT_NODE)
 			continue;
 
 		if (g_strcmp0 ((gchar*) iter->name, "p") == 0) {
-			content = (gchar*) xmlNodeGetContent (iter);
+			g_auto(GStrv) strv = NULL;
+			g_autofree gchar *tmp = NULL;
+			g_autofree gchar *content = (gchar*) xmlNodeGetContent (iter);
+			g_strstrip (content);
+
+			/* remove extra whitespaces */
+			strv = g_strsplit (content, "\n", -1);
+			for (guint i = 0; strv[i] != NULL; ++i)
+				g_strstrip (strv[i]);
+			tmp = g_strjoinv ("\n", strv);
+
 			if (str->len > 0)
 				g_string_append (str, "\n");
-			g_string_append_printf (str, "%s\n", content);
-			g_free (content);
+			g_string_append_printf (str, "%s\n", tmp);
 		} else if ((g_strcmp0 ((gchar*) iter->name, "ul") == 0) || (g_strcmp0 ((gchar*) iter->name, "ol") == 0)) {
 			/* iterate over itemize contents */
 			for (iter2 = iter->children; iter2 != NULL; iter2 = iter2->next) {
 				if (iter2->type != XML_ELEMENT_NODE)
 					continue;
 				if (g_strcmp0 ((gchar*) iter2->name, "li") == 0) {
-					content = (gchar*) xmlNodeGetContent (iter2);
-					g_string_append_printf (str,
-								" • %s\n",
+					g_autofree gchar *content = (gchar*) xmlNodeGetContent (iter2);
+					g_strstrip (content);
+					if (to_kind == AS_MARKUP_KIND_MARKDOWN) {
+						g_string_append_printf (str,
+								" - %s\n",
 								content);
-					g_free (content);
+					} else {
+						g_string_append_printf (str,
+									" • %s\n",
+									content);
+					}
 				} else {
 					/* only <li> is valid in lists */
 					ret = FALSE;
@@ -163,6 +181,21 @@ out:
 	return formatted;
 }
 
+/**
+ * as_description_markup_convert_simple:
+ * @markup: the XML markup to transform.
+ * @error: A #GError or %NULL.
+ *
+ * Converts an XML description markup into a simple printable form.
+ *
+ * Returns: (transfer full): a newly allocated %NULL terminated string.
+ **/
+gchar*
+as_markup_convert_simple (const gchar *markup, GError **error)
+{
+	return as_description_markup_convert (markup, AS_MARKUP_KIND_TEXT, error);
+}
+
 /**
  * as_str_empty:
  * @str: The string to test.
@@ -837,7 +870,7 @@ as_utils_search_token_valid (const gchar *token)
 
 /**
  * as_utils_is_category_id:
- * @category_name: an XDG category name, e.g. "ProjectManagement"
+ * @category_name: a XDG category name, e.g. "ProjectManagement"
  *
  * Searches the known list of registered XDG category names.
  * See https://specifications.freedesktop.org/menu-spec/menu-spec-1.0.html#category-registry
@@ -1113,6 +1146,12 @@ as_utils_build_data_id (AsComponentScope scope,
 			AsBundleKind bundle_kind,
 			const gchar *cid)
 {
+	/* if we have a package in system scope, the origin is "os", as they share the same namespace
+	 * and we can not have multiple versions of the same software installed on the system.
+	 * The data ID is needed to deduplicate entries */
+	if ((scope == AS_COMPONENT_SCOPE_SYSTEM) && (bundle_kind == AS_BUNDLE_KIND_PACKAGE))
+		origin = "os";
+
 	/* build the data-id */
 	return g_strdup_printf ("%s/%s/%s/%s",
 				as_component_scope_to_string (scope),
@@ -1168,22 +1207,15 @@ as_utils_get_component_bundle_kind (AsComponent *cpt)
 gchar*
 as_utils_build_data_id_for_cpt (AsComponent *cpt)
 {
-	const gchar *origin;
 	AsBundleKind bundle_kind;
 
 	/* determine bundle - what should we do if there are multiple bundles of different types
 	 * defined for one component? */
 	bundle_kind = as_utils_get_component_bundle_kind (cpt);
 
-	/* NOTE: packages share one namespace, therefore we edit the origin here for now. */
-	if (bundle_kind == AS_BUNDLE_KIND_PACKAGE)
-		origin = "os";
-	else
-		origin = as_component_get_origin (cpt);
-
 	/* build the data-id */
 	return as_utils_build_data_id (as_component_get_scope (cpt),
-					origin,
+					as_component_get_origin (cpt),
 					bundle_kind,
 					as_component_get_id (cpt));
 }
@@ -1229,3 +1261,116 @@ as_utils_dns_to_rdns (const gchar *url, const gchar *suffix)
 
 	return g_string_free (new_cid, FALSE);
 }
+
+/**
+ * as_sort_components_by_score_cb:
+ *
+ * Helper method to sort result arrays by the #AsComponent match score
+ * with higher scores appearing higher in the list.
+ */
+static gint
+as_sort_components_by_score_cb (gconstpointer a, gconstpointer b)
+{
+	guint s1, s2;
+	AsComponent *cpt1 = *((AsComponent **) a);
+	AsComponent *cpt2 = *((AsComponent **) b);
+	s1 = as_component_get_sort_score (cpt1);
+	s2 = as_component_get_sort_score (cpt2);
+
+	if (s1 > s2)
+		return -1;
+	if (s1 < s2)
+		return 1;
+	return 0;
+}
+
+/**
+ * as_sort_components_by_score:
+ *
+ * Sort components by their (search) match score.
+ */
+void
+as_sort_components_by_score (GPtrArray *cpts)
+{
+	g_ptr_array_sort (cpts, as_sort_components_by_score_cb);
+}
+
+/**
+ * as_object_ptr_array_absorb:
+ *
+ * Append contents from source array of GObjects to destination array,
+ * transferring ownership to the destination and removing values
+ * from the source (effectively moving the data).
+ * The source array will be empty afterwards.
+ *
+ * This function assumes that a GDestroyNotify function is set on the
+ * GPtrArray if GLib < 2.58.
+ */
+void
+as_object_ptr_array_absorb (GPtrArray *dest, GPtrArray *src)
+{
+#if GLIB_CHECK_VERSION(2,58,0)
+	while (src->len != 0)
+		g_ptr_array_add (dest, g_ptr_array_steal_index_fast (src, 0));
+#else
+	while (src->len != 0) {
+		g_ptr_array_add (dest, g_object_ref (g_ptr_array_index (src, 0)));
+		g_ptr_array_remove_index_fast (src, 0);
+	}
+#endif
+}
+
+/**
+ * as_ptr_array_to_str:
+ *
+ * Convert a string GPtrArray to a single string with
+ * the array values separated by a separator.
+ */
+gchar*
+as_ptr_array_to_str (GPtrArray *array, const gchar *separator)
+{
+	GString *str;
+	if ((array == NULL) || (array->len == 0))
+		return NULL;
+
+	str = g_string_new ("");
+	for (guint i = 0; i < array->len; i++) {
+		g_string_append_printf (str,
+					"%s%s",
+					(const gchar*) g_ptr_array_index (array, i),
+					separator);
+	}
+	if (str->len >= 1)
+		g_string_truncate (str, str->len -1);
+
+	return g_string_free (str, FALSE);
+}
+
+/**
+ * as_filebasename_from_uri:
+ *
+ * Get the file basename from an URI.
+ * This is the last component of the path, with any query or fragment
+ * stripped off.
+ *
+ * Returns: The filename.
+ */
+gchar*
+as_filebasename_from_uri (const gchar *uri)
+{
+	gchar *tmp;
+	gchar *bname;
+
+	if (uri == NULL)
+		return NULL;
+	bname = g_path_get_basename (uri);
+
+	tmp = g_strstr_len (bname, -1, "?");
+	if (tmp != NULL)
+		tmp[0] = '\0';
+	tmp = g_strstr_len (bname, -1, "#");
+	if (tmp != NULL)
+		tmp[0] = '\0';
+
+	return bname;
+}
