@@ -52,6 +52,7 @@ void		as_xml_parse_metainfo_description_node (AsContext *ctx,
 							GHFunc func,
 							gpointer entity);
 
+gchar		*as_xml_dump_node_content (xmlNode *node);
 gchar		*as_xml_dump_node_children (xmlNode *node);
 
 void		as_xml_add_description_node (AsContext *ctx,
@@ -77,6 +78,7 @@ xmlNode		*as_xml_add_text_node (xmlNode *root,
 					const gchar *value);
 
 xmlDoc		*as_xml_parse_document (const gchar *data,
+					gssize len,
 					GError **error);
 
 gchar		*as_xml_node_to_str (xmlNode *root, GError **error);
