@@ -145,11 +145,11 @@ test_appstream_write_locale ()
 	const gchar *EXPECTED_XML = "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n"
 				    "<component type=\"desktop-application\">\n"
 				    "  <id>firefox.desktop</id>\n"
-				    "  <name xml:lang=\"fr_FR\">Firefoux</name>\n"
 				    "  <name>Firefox</name>\n"
 				    "  <name xml:lang=\"de_DE\">Feuerfuchs</name>\n"
-				    "  <summary xml:lang=\"fr_FR\">Navigateur web</summary>\n"
+				    "  <name xml:lang=\"fr_FR\">Firefoux</name>\n"
 				    "  <summary>Web browser</summary>\n"
+				    "  <summary xml:lang=\"fr_FR\">Navigateur web</summary>\n"
 				    "  <pkgname>firefox-bin</pkgname>\n"
 				    "  <categories>\n"
 				    "    <category>network</category>\n"
@@ -305,28 +305,25 @@ test_appstream_write_description ()
 						"  <summary xml:lang=\"de\">Nur ein Unittest.</summary>\n"
 						"  <description>\n"
 						"    <p>First paragraph</p>\n"
+						"    <p xml:lang=\"de\">Erster paragraph</p>\n"
 						"    <ol>\n"
 						"      <li>One</li>\n"
+						"      <li xml:lang=\"de\">Eins</li>\n"
 						"      <li>Two</li>\n"
+						"      <li xml:lang=\"de\">Zwei</li>\n"
 						"      <li>Three is &gt; 2 &amp; 1</li>\n"
+						"      <li xml:lang=\"de\">Drei</li>\n"
 						"    </ol>\n"
 						"    <p>Paragraph2</p>\n"
+						"    <p xml:lang=\"de\">Zweiter Paragraph</p>\n"
 						"    <ul>\n"
 						"      <li>First</li>\n"
+						"      <li xml:lang=\"de\">Erstens</li>\n"
 						"      <li>Second</li>\n"
+						"      <li xml:lang=\"de\">Zweitens</li>\n"
 						"    </ul>\n"
 						"    <p>Paragraph3 &amp; the last one</p>\n"
-						"    <p xml:lang=\"de\">First paragraph</p>\n"
-						"    <ol>\n"
-						"      <li xml:lang=\"de\">One</li>\n"
-						"      <li xml:lang=\"de\">Two</li>\n"
-						"      <li xml:lang=\"de\">Three</li>\n"
-						"    </ol>\n"
-						"    <ul>\n"
-						"      <li xml:lang=\"de\">First</li>\n"
-						"      <li xml:lang=\"de\">Second</li>\n"
-						"    </ul>\n"
-						"    <p xml:lang=\"de\">Paragraph2</p>\n"
+						"    <p xml:lang=\"de\">Paragraph3</p>\n"
 						"  </description>\n"
 						"  <icon type=\"cached\" width=\"20\" height=\"20\">test_writetest.png</icon>\n"
 						"  <icon type=\"cached\" width=\"40\" height=\"40\">test_writetest.png</icon>\n"
@@ -358,17 +355,18 @@ test_appstream_write_description ()
 					   "      <p>Paragraph3 &amp; the last one</p>\n"
 					   "    </description>\n"
 					   "    <description xml:lang=\"de\">\n"
-					   "      <p>First paragraph</p>\n"
+					   "      <p>Erster paragraph</p>\n"
 					   "      <ol>\n"
-					   "        <li>One</li>\n"
-					   "        <li>Two</li>\n"
-					   "        <li>Three</li>\n"
+					   "        <li>Eins</li>\n"
+					   "        <li>Zwei</li>\n"
+					   "        <li>Drei</li>\n"
 					   "      </ol>\n"
+					   "      <p>Zweiter Paragraph</p>\n"
 					   "      <ul>\n"
-					   "        <li>First</li>\n"
-					   "        <li>Second</li>\n"
+					   "        <li>Erstens</li>\n"
+					   "        <li>Zweitens</li>\n"
 					   "      </ul>\n"
-					   "      <p>Paragraph2</p>\n"
+					   "      <p>Paragraph3</p>\n"
 					   "    </description>\n"
 					   "    <icon type=\"cached\" width=\"20\" height=\"20\">test_writetest.png</icon>\n"
 					   "    <icon type=\"cached\" width=\"40\" height=\"40\">test_writetest.png</icon>\n"
@@ -423,7 +421,7 @@ test_appstream_write_description ()
 	/* add localization */
 	as_component_set_summary (cpt, "Nur ein Unittest.", "de");
 	as_component_set_description (cpt,
-				"<p>First paragraph</p>\n<ol><li>One</li><li>Two</li><li>Three</li></ol><ul><li>First</li><li>Second</li></ul><p>Paragraph2</p>",
+				"<p>Erster paragraph</p>\n<ol><li>Eins</li><li>Zwei</li><li>Drei</li></ol><p>Zweiter Paragraph</p><ul><li>Erstens</li><li>Zweitens</li></ul><p>Paragraph3</p>",
 				"de");
 
 	tmp = as_metadata_component_to_metainfo (metad, AS_FORMAT_KIND_XML, NULL);
@@ -447,10 +445,12 @@ test_appstream_read_description (void)
 	const gchar *xmldata_desc_mi1 = "<component>\n"
 					"  <id>org.example.DescTestMI-1</id>\n"
 					"  <description>\n"
-					"    <p>Agenda is a simple, slick, speedy and no-nonsense task manager. Use it to keep track of the tasks that matter most.</p>\n"
+					"    <p>Agenda is a simple, slick, <em>speedy</em> and no-nonsense task manager. Use it to keep track of the tasks that matter most.</p>\n"
+					"    <p>This paragraph makes use of <code>code markup</code>.</p>\n"
 					"    <ul>\n"
-					"      <li>Blazingly fast and light</li>\n"
+					"      <li>Blazingly <em>fast</em> and light</li>\n"
 					"      <li>Remembers your list until you clear completed tasks</li>\n"
+					"      <li>Some <code>code</code> item</li>\n"
 					"      <li>...</li>\n"
 					"    </ul>\n"
 					"    <p>I dare you to find an easier, faster, more beautiful task manager for elementary OS.</p>\n"
@@ -472,13 +472,16 @@ test_appstream_read_description (void)
 	cpt = as_xml_test_read_data (xmldata_desc_mi1, AS_FORMAT_STYLE_METAINFO);
 	g_assert_cmpstr (as_component_get_id (cpt), ==, "org.example.DescTestMI-1");
 
-	g_assert_cmpstr (as_component_get_description (cpt), ==, "<p>Agenda is a simple, slick, speedy and no-nonsense task manager. Use it to keep track of the tasks that matter most.</p>\n"
-								 "<ul>\n"
-								 "  <li>Blazingly fast and light</li>\n"
-								 "  <li>Remembers your list until you clear completed tasks</li>\n"
-								 "  <li>...</li>\n"
-								 "</ul>\n"
-								 "<p>I dare you to find an easier, faster, more beautiful task manager for elementary OS.</p>\n");
+	g_assert (as_test_compare_lines (as_component_get_description (cpt),
+					 "<p>Agenda is a simple, slick, <em>speedy</em> and no-nonsense task manager. Use it to keep track of the tasks that matter most.</p>\n"
+					 "<p>This paragraph makes use of <code>code markup</code>.</p>\n"
+					 "<ul>\n"
+					 "  <li>Blazingly <em>fast</em> and light</li>\n"
+					 "  <li>Remembers your list until you clear completed tasks</li>\n"
+					 "  <li>Some <code>code</code> item</li>\n"
+					 "  <li>...</li>\n"
+					 "</ul>\n"
+					 "<p>I dare you to find an easier, faster, more beautiful task manager for elementary OS.</p>\n"));
 
 	g_object_unref (cpt);
 	cpt = as_xml_test_read_data (xmldata_desc_mi2, AS_FORMAT_STYLE_METAINFO);
@@ -897,8 +900,8 @@ test_appstream_write_metainfo_to_collection (void)
 					   "<components version=\"0.12\">\n"
 					   "  <component>\n"
 					   "    <id>org.example.Test</id>\n"
-					   "    <name xml:lang=\"de\">Test</name>\n"
 					   "    <name>Test</name>\n"
+					   "    <name xml:lang=\"de\">Test</name>\n"
 					   "    <name xml:lang=\"eo\">Testo</name>\n"
 					   "    <summary>Just a unittest.</summary>\n"
 					   "    <summary xml:lang=\"de\">Nur ein Unittest.</summary>\n"
@@ -961,8 +964,8 @@ static const gchar *xmldata_screenshots = "<?xml version=\"1.0\" encoding=\"utf-
 					"  <id>org.example.ScreenshotTest</id>\n"
 					"  <screenshots>\n"
 					"    <screenshot type=\"default\">\n"
-					"      <caption xml:lang=\"de_DE\">Das Hauptfenster, welches irgendwas zeigt</caption>\n"
 					"      <caption>The main window displaying a thing</caption>\n"
+					"      <caption xml:lang=\"de_DE\">Das Hauptfenster, welches irgendwas zeigt</caption>\n"
 					"      <image type=\"source\" width=\"1916\" height=\"1056\">https://example.org/alpha.png</image>\n"
 					"      <image type=\"thumbnail\" width=\"800\" height=\"600\">https://example.org/alpha_small.png</image>\n"
 					"    </screenshot>\n"
@@ -971,6 +974,10 @@ static const gchar *xmldata_screenshots = "<?xml version=\"1.0\" encoding=\"utf-
 					"      <image type=\"thumbnail\" width=\"800\" height=\"600\">https://example.org/beta_small.png</image>\n"
 					"      <image type=\"source\" xml:lang=\"de_DE\">https://example.org/localized_de.png</image>\n"
 					"    </screenshot>\n"
+					"    <screenshot>\n"
+					"      <video codec=\"av1\" container=\"matroska\" width=\"1916\" height=\"1056\">https://example.org/screencast.mkv</video>\n"
+					"      <video codec=\"av1\" container=\"matroska\" width=\"1916\" height=\"1056\" xml:lang=\"de_DE\">https://example.org/screencast_de.mkv</video>\n"
+					"    </screenshot>\n"
 					"  </screenshots>\n"
 					"</component>\n";
 
@@ -986,8 +993,11 @@ test_xml_read_screenshots (void)
 	GPtrArray *screenshots;
 	AsScreenshot *scr1;
 	AsScreenshot *scr2;
+	AsScreenshot *scr3;
 	GPtrArray *images;
+	GPtrArray *videos;
 	AsImage *img;
+	AsVideo *vid;
 
 	const gchar *xmldata_screenshot_legacy = "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n"
 					"<component>\n"
@@ -1001,13 +1011,15 @@ test_xml_read_screenshots (void)
 	g_assert_cmpstr (as_component_get_id (cpt), ==, "org.example.ScreenshotTest");
 
 	screenshots = as_component_get_screenshots (cpt);
-	g_assert_cmpint (screenshots->len, ==, 2);
+	g_assert_cmpint (screenshots->len, ==, 3);
 
 	scr1 = AS_SCREENSHOT (g_ptr_array_index (screenshots, 0));
 	scr2 = AS_SCREENSHOT (g_ptr_array_index (screenshots, 1));
+	scr3 = AS_SCREENSHOT (g_ptr_array_index (screenshots, 2));
 
 	/* screenshot 1 */
 	g_assert_cmpint (as_screenshot_get_kind (scr1), ==, AS_SCREENSHOT_KIND_DEFAULT);
+	g_assert_cmpint (as_screenshot_get_media_kind (scr1), ==, AS_SCREENSHOT_MEDIA_KIND_IMAGE);
 	as_screenshot_set_active_locale (scr1, "C");
 	g_assert_cmpstr (as_screenshot_get_caption (scr1), ==, "The main window displaying a thing");
 	as_screenshot_set_active_locale (scr1, "de_DE");
@@ -1030,6 +1042,7 @@ test_xml_read_screenshots (void)
 
 	/* screenshot 2 */
 	g_assert_cmpint (as_screenshot_get_kind (scr2), ==, AS_SCREENSHOT_KIND_EXTRA);
+	g_assert_cmpint (as_screenshot_get_media_kind (scr2), ==, AS_SCREENSHOT_MEDIA_KIND_IMAGE);
 	as_screenshot_set_active_locale (scr2, "C");
 	images = as_screenshot_get_images (scr2);
 	g_assert_cmpint (images->len, ==, 2);
@@ -1054,6 +1067,37 @@ test_xml_read_screenshots (void)
 	g_assert_cmpint (as_image_get_width (img), ==, 800);
 	g_assert_cmpint (as_image_get_height (img), ==, 600);
 
+	/* screenshot 3 */
+	g_assert_cmpint (as_screenshot_get_kind (scr3), ==, AS_SCREENSHOT_KIND_EXTRA);
+	g_assert_cmpint (as_screenshot_get_media_kind (scr3), ==, AS_SCREENSHOT_MEDIA_KIND_VIDEO);
+	as_screenshot_set_active_locale (scr3, "C");
+	g_assert_cmpint (as_screenshot_get_images (scr3)->len, ==, 0);
+	videos = as_screenshot_get_videos (scr3);
+	g_assert_cmpint (videos->len, ==, 1);
+	as_screenshot_set_active_locale (scr3, "de_DE");
+	videos = as_screenshot_get_videos (scr3);
+	g_assert_cmpint (videos->len, ==, 1);
+	vid = AS_VIDEO (g_ptr_array_index (videos, 0));
+	g_assert_cmpstr (as_video_get_url (vid), ==, "https://example.org/screencast_de.mkv");
+
+	as_screenshot_set_active_locale (scr3, "ALL");
+	videos = as_screenshot_get_videos (scr3);
+	g_assert_cmpint (videos->len, ==, 2);
+
+	vid = AS_VIDEO (g_ptr_array_index (videos, 0));
+	g_assert_cmpint (as_video_get_codec_kind (vid), ==, AS_VIDEO_CODEC_KIND_AV1);
+	g_assert_cmpint (as_video_get_container_kind (vid), ==, AS_VIDEO_CONTAINER_KIND_MKV);
+	g_assert_cmpstr (as_video_get_url (vid), ==, "https://example.org/screencast.mkv");
+	g_assert_cmpint (as_video_get_width (vid), ==, 1916);
+	g_assert_cmpint (as_video_get_height (vid), ==, 1056);
+
+	vid = AS_VIDEO (g_ptr_array_index (videos, 1));
+	g_assert_cmpint (as_video_get_codec_kind (vid), ==, AS_VIDEO_CODEC_KIND_AV1);
+	g_assert_cmpint (as_video_get_container_kind (vid), ==, AS_VIDEO_CONTAINER_KIND_MKV);
+	g_assert_cmpstr (as_video_get_url (vid), ==, "https://example.org/screencast_de.mkv");
+	g_assert_cmpint (as_video_get_width (vid), ==, 1916);
+	g_assert_cmpint (as_video_get_height (vid), ==, 1056);
+
 	/* test a legacy screenshot entry that we briefly supported in an older AppStream release */
 	g_object_unref (cpt);
 	cpt = as_xml_test_read_data (xmldata_screenshot_legacy, AS_FORMAT_STYLE_METAINFO);
@@ -1084,7 +1128,9 @@ test_xml_write_screenshots (void)
 	g_autofree gchar *res = NULL;
 	g_autoptr(AsScreenshot) scr1 = NULL;
 	g_autoptr(AsScreenshot) scr2 = NULL;
+	g_autoptr(AsScreenshot) scr3 = NULL;
 	AsImage *img;
+	AsVideo *vid;
 
 	cpt = as_component_new ();
 	as_component_set_id (cpt, "org.example.ScreenshotTest");
@@ -1133,8 +1179,29 @@ test_xml_write_screenshots (void)
 	as_screenshot_add_image (scr2, img);
 	g_object_unref (img);
 
+	scr3 = as_screenshot_new ();
+	vid = as_video_new ();
+	as_video_set_codec_kind (vid, AS_VIDEO_CODEC_KIND_AV1);
+	as_video_set_container_kind (vid, AS_VIDEO_CONTAINER_KIND_MKV);
+	as_video_set_width (vid, 1916);
+	as_video_set_height (vid, 1056);
+	as_video_set_url (vid, "https://example.org/screencast.mkv");
+	as_screenshot_add_video (scr3, vid);
+	g_object_unref (vid);
+
+	vid = as_video_new ();
+	as_video_set_codec_kind (vid, AS_VIDEO_CODEC_KIND_AV1);
+	as_video_set_container_kind (vid, AS_VIDEO_CONTAINER_KIND_MKV);
+	as_video_set_locale (vid, "de_DE");
+	as_video_set_width (vid, 1916);
+	as_video_set_height (vid, 1056);
+	as_video_set_url (vid, "https://example.org/screencast_de.mkv");
+	as_screenshot_add_video (scr3, vid);
+	g_object_unref (vid);
+
 	as_component_add_screenshot (cpt, scr1);
 	as_component_add_screenshot (cpt, scr2);
+	as_component_add_screenshot (cpt, scr3);
 
 	res = as_xml_test_serialize (cpt, AS_FORMAT_STYLE_METAINFO);
 	g_assert (as_test_compare_lines (res, xmldata_screenshots));
@@ -1262,8 +1329,8 @@ static const gchar *xmldata_agreements = "<?xml version=\"1.0\" encoding=\"utf-8
 						"  <id>org.example.AgreementsTest</id>\n"
 						"  <agreement type=\"eula\" version_id=\"1.2.3a\">\n"
 						"    <agreement_section type=\"intro\">\n"
-						"      <name xml:lang=\"de_DE\">Einführung</name>\n"
 						"      <name>Intro</name>\n"
+						"      <name xml:lang=\"de_DE\">Einführung</name>\n"
 						"      <description>\n"
 						"        <p>Mighty Fine</p>\n"
 						"      </description>\n"
@@ -1348,6 +1415,10 @@ static const gchar *xmldata_releases = "<?xml version=\"1.0\" encoding=\"utf-8\"
 					"        <p xml:lang=\"de\">Eine Beschreibung der Veröffentlichung.</p>\n"
 					"      </description>\n"
 					"      <url>https://example.org/releases/1.2.html</url>\n"
+					"      <issues>\n"
+					"        <issue url=\"https://example.com/bugzilla/12345\">bz#12345</issue>\n"
+					"        <issue type=\"cve\">CVE-2019-123456</issue>\n"
+					"      </issues>\n"
 					"      <artifacts>\n"
 					"        <artifact type=\"binary\" platform=\"x86_64-linux-gnu\" bundle=\"tarball\">\n"
 					"          <location>https://example.com/mytarball.bin.tar.xz</location>\n"
@@ -1374,6 +1445,7 @@ test_xml_read_releases (void)
 	g_autoptr(AsComponent) cpt = NULL;
 	AsRelease *rel;
 	GPtrArray *artifacts;
+	GPtrArray *issues;
 
 	cpt = as_xml_test_read_data (xmldata_releases, AS_FORMAT_STYLE_METAINFO);
 	g_assert_cmpstr (as_component_get_id (cpt), ==, "org.example.ReleaseTest");
@@ -1420,6 +1492,24 @@ test_xml_read_releases (void)
 			g_assert_not_reached ();
 		}
 	}
+
+	issues = as_release_get_issues (rel);
+	g_assert_cmpint (issues->len, ==, 2);
+	for (guint i = 0; i < issues->len; i++) {
+		AsIssue *issue = AS_ISSUE (g_ptr_array_index (issues, i));
+
+		if (as_issue_get_kind (issue) == AS_ISSUE_KIND_GENERIC) {
+			g_assert_cmpstr (as_issue_get_id (issue), ==, "bz#12345");
+			g_assert_cmpstr (as_issue_get_url (issue), ==, "https://example.com/bugzilla/12345");
+
+		} else if (as_issue_get_kind (issue) == AS_ISSUE_KIND_CVE) {
+			g_assert_cmpstr (as_issue_get_id (issue), ==, "CVE-2019-123456");
+			g_assert_cmpstr (as_issue_get_url (issue), ==, "https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-123456");
+
+		} else {
+			g_assert_not_reached ();
+		}
+	}
 }
 
 /**
@@ -1435,6 +1525,7 @@ test_xml_write_releases (void)
 	g_autofree gchar *res = NULL;
 	AsArtifact *artifact;
 	AsChecksum *cs;
+	AsIssue *issue;
 
 	cpt = as_component_new ();
 	as_component_set_id (cpt, "org.example.ReleaseTest");
@@ -1472,6 +1563,19 @@ test_xml_write_releases (void)
 	as_release_add_artifact (rel, artifact);
 	g_object_unref (artifact);
 
+	/* issues */
+	issue = as_issue_new ();
+	as_issue_set_id (issue, "bz#12345");
+	as_issue_set_url (issue, "https://example.com/bugzilla/12345");
+	as_release_add_issue (rel, issue);
+	g_object_unref (issue);
+
+	issue = as_issue_new ();
+	as_issue_set_kind (issue, AS_ISSUE_KIND_CVE);
+	as_issue_set_id (issue, "CVE-2019-123456");
+	as_release_add_issue (rel, issue);
+	g_object_unref (issue);
+
 	as_component_add_release (cpt, rel);
 
 	res = as_xml_test_serialize (cpt, AS_FORMAT_STYLE_METAINFO);
