@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2015-2016 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2015-2019 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -72,32 +72,37 @@ static int
 ascli_get_component_pkgnames (const gchar *identifier, gchar ***pkgnames)
 {
 	g_autoptr(GError) error = NULL;
-	g_autoptr(AsDataPool) dpool = NULL;
-	g_autoptr(AsComponent) cpt = NULL;
+	g_autoptr(AsPool) dpool = NULL;
+	g_autoptr(GPtrArray) result = NULL;
+	AsComponent *cpt;
 
 	if (identifier == NULL) {
-		ascli_print_stderr (_("You need to specify a component-id."));
+		ascli_print_stderr (_("You need to specify a component-ID."));
 		return 2;
 	}
 
-	dpool = as_data_pool_new ();
-	as_data_pool_load (dpool, NULL, &error);
+	dpool = as_pool_new ();
+	as_pool_load (dpool, NULL, &error);
 	if (error != NULL) {
 		g_printerr ("%s\n", error->message);
 		return 1;
 	}
 
-	cpt = as_data_pool_get_component_by_id (dpool, identifier);
-	if (cpt == NULL) {
-		ascli_print_stderr (_("Unable to find component with id '%s'!"), identifier);
+	result = as_pool_get_components_by_id (dpool, identifier);
+	if (result->len == 0) {
+		ascli_print_stderr (_("Unable to find component with ID '%s'!"), identifier);
 		return 4;
 	}
 
+	/* FIXME: Ask user which component they want to install? */
+	cpt = AS_COMPONENT (g_ptr_array_index (result, 0));
+
 	/* we need a variable to take the pkgnames array */
 	g_assert (pkgnames != NULL);
 
 	*pkgnames = g_strdupv (as_component_get_pkgnames (cpt));
 	if (*pkgnames == NULL) {
+		/* TRANSLATORS: We found no distribution package or bundle to install to make this software available */
 		ascli_print_stderr (_("Component '%s' has no installation candidate."), identifier);
 		return 1;
 	}
